@@ -22,8 +22,23 @@ package org.videolan.libvlc;
 
 abstract class VLCEvent {
     public final int type;
+    protected final long arg1;
+    protected final float arg2;
+
     protected VLCEvent(int type) {
         this.type = type;
+        this.arg1 = 0;
+        this.arg2 = 0;
+    }
+    protected VLCEvent(int type, long arg1) {
+        this.type = type;
+        this.arg1 = arg1;
+        this.arg2 = 0;
+    }
+    protected VLCEvent(int type, float arg2) {
+        this.type = type;
+        this.arg1 = 0;
+        this.arg2 = arg2;
     }
 
     /**
