@@ -217,6 +217,11 @@ public class MainActivity extends AudioPlayerContainerActivity implements Search
             item.setTitle(R.string.open);
         }
 
+        if (BuildConfig.DEBUG) {
+            mNavigationView.getMenu().findItem(R.id.nav_history).setVisible(true);
+            mNavigationView.getMenu().findItem(R.id.nav_network).setVisible(true);
+        }
+
         if (AndroidUtil.isLolliPopOrLater())
             mNavigationView.setPadding(0, mNavigationView.getPaddingTop()/2, 0, 0);
     }
